@@ -1,16 +1,16 @@
 //
-//  ISORegion.swift
-//  mas
+// ISORegion.swift
+// mas
 //
-//  Created by Ross Goldberg on 2024-12-29.
-//  Copyright (c) 2024 mas-cli. All rights reserved.
+// Copyright © 2024 mas-cli. All rights reserved.
 //
 
-import IsoCountryCodes
-import StoreKit
+private import IsoCountryCodes
+private import StoreKit
 
 // periphery:ignore
 protocol ISORegion {
+	// swiftlint:disable unused_declaration
 	var name: String { get }
 	var numeric: String { get }
 	var alpha2: String { get }
@@ -20,6 +20,7 @@ protocol ISORegion {
 	var continent: String { get }
 	var flag: String? { get }
 	var fractionDigits: Int { get }
+	// swiftlint:enable unused_declaration
 }
 
 extension IsoCountryInfo: ISORegion {}
