@@ -1,21 +1,21 @@
 //
-//  Config.swift
-//  mas
+// Config.swift
+// mas
 //
-//  Created by Ross Goldberg on 2025-01-03.
-//  Copyright © 2024 mas-cli. All rights reserved.
+// Copyright © 2025 mas-cli. All rights reserved.
 //
 
-import ArgumentParser
-import Foundation
+internal import ArgumentParser
+private import Foundation
 
-private let unknown = "unknown"
+private var unknown: String { "unknown" }
+private var sysCtlByName: String { "sysctlbyname" }
 
 extension MAS {
-	/// Displays mas config & related system info.
+	/// Outputs mas config & related system info.
 	struct Config: AsyncParsableCommand {
 		static let configuration = CommandConfiguration(
-			abstract: "Display mas config & related system info"
+			abstract: "Output mas config & related system info"
 		)
 
 		@Flag(help: "Output as Markdown")
@@ -23,10 +23,14 @@ extension MAS {
 
 		/// Runs the command.
 		func run() async throws {
+			try await mas.run { await run(printer: $0) }
+		}
+
+		func run(printer: Printer) async {
 			if markdown {
-				print("```text")
+				printer.info("```text")
 			}
-			print(
+			printer.info(
 				"""
 				mas ▁▁▁▁ \(Package.version)
 				arch ▁▁▁ \(configStringValue("hw.machine"))
@@ -37,15 +41,14 @@ extension MAS {
 				swift ▁▁ \(Package.swiftVersion)
 				region ▁ \(await isoRegion?.alpha2 ?? unknown)
 				macos ▁▁ \(
-					ProcessInfo.processInfo.operatingSystemVersionString.dropFirst(8)
-						.replacingOccurrences(of: "Build ", with: "")
+					ProcessInfo.processInfo.operatingSystemVersionString.dropFirst(8).replacingOccurrences(of: "Build ", with: "")
 				)
 				mac ▁▁▁▁ \(configStringValue("hw.product"))
 				cpu ▁▁▁▁ \(configStringValue("machdep.cpu.brand_string"))
 				"""
 			)
 			if markdown {
-				print("```")
+				printer.info("```")
 			}
 		}
 	}
@@ -54,13 +57,13 @@ extension MAS {
 private func configStringValue(_ name: String) -> String {
 	var size = 0
 	guard sysctlbyname(name, nil, &size, nil, 0) == 0 else {
-		perror("sysctlbyname")
+		perror(sysCtlByName)
 		return unknown
 	}
 
 	var buffer = [CChar](repeating: 0, count: size)
 	guard sysctlbyname(name, &buffer, &size, nil, 0) == 0 else {
-		perror("sysctlbyname")
+		perror(sysCtlByName)
 		return unknown
 	}
 
