@@ -1,18 +1,17 @@
 //
-//  List.swift
-//  mas
+// List.swift
+// mas
 //
-//  Created by Andrew Naylor on 21/08/2015.
-//  Copyright (c) 2015 Andrew Naylor. All rights reserved.
+// Copyright © 2015 mas-cli. All rights reserved.
 //
 
-import ArgumentParser
+internal import ArgumentParser
 
 extension MAS {
-	/// Command which lists all installed apps.
+	/// Lists all apps installed from the Mac App Store.
 	struct List: AsyncParsableCommand {
 		static let configuration = CommandConfiguration(
-			abstract: "List apps installed from the Mac App Store"
+			abstract: "List all apps installed from the Mac App Store"
 		)
 
 		/// Runs the command.
@@ -21,8 +20,12 @@ extension MAS {
 		}
 
 		func run(installedApps: [InstalledApp]) throws {
+			try mas.run { run(printer: $0, installedApps: installedApps) }
+		}
+
+		private func run(printer: Printer, installedApps: [InstalledApp]) {
 			if installedApps.isEmpty {
-				printError(
+				printer.error(
 					"""
 					No installed apps found
 
@@ -33,7 +36,7 @@ extension MAS {
 					"""
 				)
 			} else {
-				print(AppListFormatter.format(installedApps))
+				printer.info(AppListFormatter.format(installedApps))
 			}
 		}
 	}
