@@ -1,18 +1,20 @@
 //
-//  Open.swift
-//  mas
+// Open.swift
+// mas
 //
-//  Created by Ben Chatelain on 2018-12-29.
-//  Copyright © 2016 mas-cli. All rights reserved.
+// Copyright © 2018 mas-cli. All rights reserved.
 //
 
-import AppKit
-import ArgumentParser
+private import AppKit
+internal import ArgumentParser
 
-private let masScheme = "macappstore"
+private var masScheme: String { "macappstore" }
 
 extension MAS {
-	/// Opens app page in MAS app. Uses the iTunes Lookup API:
+	/// Opens app page in 'App Store.app'.
+	///
+	/// Uses the iTunes Lookup API:
+	///
 	/// https://performance-partners.apple.com/search-api
 	struct Open: AsyncParsableCommand {
 		static let configuration = CommandConfiguration(
@@ -28,11 +30,16 @@ extension MAS {
 		}
 
 		func run(searcher: AppStoreSearcher) async throws {
+			try await mas.run { try await run(printer: $0, searcher: searcher) }
+		}
+
+		private func run(printer _: Printer, searcher: AppStoreSearcher) async throws {
 			guard let appID else {
-				// If no app ID is given, just open the MAS GUI app
+				// If no app ID was given, just open the MAS GUI app
 				try await openMacAppStore()
 				return
 			}
+
 			try await openInMacAppStore(pageForAppID: appID, searcher: searcher)
 		}
 	}
@@ -40,10 +47,10 @@ extension MAS {
 
 private func openMacAppStore() async throws {
 	guard let macappstoreSchemeURL = URL(string: "macappstore:") else {
-		throw MASError.notSupported
+		throw MASError.runtimeError("Failed to create URL from macappstore scheme")
 	}
 	guard let appURL = NSWorkspace.shared.urlForApplication(toOpen: macappstoreSchemeURL) else {
-		throw MASError.notSupported
+		throw MASError.runtimeError("Failed to find app to open macappstore URLs")
 	}
 
 	try await NSWorkspace.shared.openApplication(at: appURL, configuration: NSWorkspace.OpenConfiguration())
@@ -53,13 +60,13 @@ private func openInMacAppStore(pageForAppID appID: AppID, searcher: AppStoreSear
 	let result = try await searcher.lookup(appID: appID)
 
 	guard var urlComponents = URLComponents(string: result.trackViewUrl) else {
-		throw MASError.runtimeError("Unable to construct URL from: \(result.trackViewUrl)")
+		throw MASError.urlParsing(result.trackViewUrl)
 	}
 
 	urlComponents.scheme = masScheme
 
 	guard let url = urlComponents.url else {
-		throw MASError.runtimeError("Unable to construct URL from: \(urlComponents)")
+		throw MASError.urlParsing(String(describing: urlComponents))
 	}
 
 	try await url.open()
