@@ -1,23 +1,22 @@
 //
-//  Outdated.swift
-//  mas
+// Outdated.swift
+// mas
 //
-//  Created by Andrew Naylor on 21/08/2015.
-//  Copyright (c) 2015 Andrew Naylor. All rights reserved.
+// Copyright © 2015 mas-cli. All rights reserved.
 //
 
-import ArgumentParser
+internal import ArgumentParser
 
 extension MAS {
-	/// Command which displays a list of installed apps which have available updates
-	/// ready to be installed from the Mac App Store.
+	/// Outputs a list of installed apps which have updates available to be
+	/// installed from the Mac App Store.
 	struct Outdated: AsyncParsableCommand {
 		static let configuration = CommandConfiguration(
 			abstract: "List pending app updates from the Mac App Store"
 		)
 
-		@Flag(help: "Display warnings about apps unknown to the Mac App Store")
-		var verbose = false
+		@OptionGroup
+		var verboseOptionGroup: VerboseOptionGroup
 
 		/// Runs the command.
 		func run() async throws {
@@ -25,11 +24,15 @@ extension MAS {
 		}
 
 		func run(installedApps: [InstalledApp], searcher: AppStoreSearcher) async throws {
+			try await mas.run { await run(printer: $0, installedApps: installedApps, searcher: searcher) }
+		}
+
+		private func run(printer: Printer, installedApps: [InstalledApp], searcher: AppStoreSearcher) async {
 			for installedApp in installedApps {
 				do {
 					let storeApp = try await searcher.lookup(appID: installedApp.id)
 					if installedApp.isOutdated(comparedTo: storeApp) {
-						print(
+						printer.info(
 							installedApp.id,
 							" ",
 							installedApp.name,
@@ -41,17 +44,8 @@ extension MAS {
 							separator: ""
 						)
 					}
-				} catch MASError.unknownAppID(let unknownAppID) {
-					if verbose {
-						printWarning(
-							"Identifier ",
-							unknownAppID,
-							" not found in store. Was expected to identify ",
-							installedApp.name,
-							".",
-							separator: ""
-						)
-					}
+				} catch {
+					verboseOptionGroup.printProblem(forError: error, expectedAppName: installedApp.name, printer: printer)
 				}
 			}
 		}
