@@ -1,13 +1,12 @@
 //
-//  Reset.swift
-//  mas
+// Reset.swift
+// mas
 //
-//  Created by Andrew Naylor on 14/09/2016.
-//  Copyright © 2016 Andrew Naylor. All rights reserved.
+// Copyright © 2016 mas-cli. All rights reserved.
 //
 
-import ArgumentParser
-import CommerceKit
+internal import ArgumentParser
+private import CommerceKit
 
 extension MAS {
 	/// Kills several macOS processes as a means to reset the app store.
@@ -21,6 +20,10 @@ extension MAS {
 
 		/// Runs the command.
 		func run() throws {
+			try mas.run { run(printer: $0) }
+		}
+
+		func run(printer: Printer) {
 			// The "Reset Application" command in the Mac App Store debug menu performs
 			// the following steps
 			//
@@ -29,7 +32,7 @@ extension MAS {
 			// - rm com.apple.appstore download directory
 			// - clear cookies (appears to be a no-op)
 			//
-			// As storeagent no longer exists we will implement a slight variant and kill all
+			// As storeagent no longer exists we will implement a slight variant & kill all
 			// App Store-associated processes
 			// - storeaccountd
 			// - storeassetd
@@ -59,9 +62,9 @@ extension MAS {
 			kill.launch()
 			kill.waitUntilExit()
 
-			if kill.terminationStatus != 0, debug {
+			if kill.terminationStatus != 0 {
 				let output = stderr.fileHandleForReading.readDataToEndOfFile()
-				printError(
+				printer.error(
 					"killall failed:",
 					String(data: output, encoding: .utf8) ?? "Error info not available",
 					separator: "\n"
@@ -69,14 +72,11 @@ extension MAS {
 			}
 
 			// Wipe Download Directory
-			if let directory = CKDownloadDirectory(nil) {
-				do {
-					try FileManager.default.removeItem(atPath: directory)
-				} catch {
-					if debug {
-						printError("removeItemAtPath:\"", directory, "\" failed, ", error, separator: "")
-					}
-				}
+			let directory = CKDownloadDirectory(nil)
+			do {
+				try FileManager.default.removeItem(atPath: directory)
+			} catch {
+				printer.error("Failed to delete download directory", directory, error: error)
 			}
 		}
 	}
