@@ -1,14 +1,14 @@
 //
-//  SignIn.swift
-//  mas
+// SignIn.swift
+// mas
 //
-//  Created by Andrew Naylor on 14/02/2016.
-//  Copyright © 2016 Andrew Naylor. All rights reserved.
+// Copyright © 2016 mas-cli. All rights reserved.
 //
 
-import ArgumentParser
+internal import ArgumentParser
 
 extension MAS {
+	/// Signs in to an Apple Account in the Mac App Store.
 	struct SignIn: ParsableCommand {
 		static let configuration = CommandConfiguration(
 			commandName: "signin",
@@ -16,15 +16,19 @@ extension MAS {
 		)
 
 		@Flag(help: "Provide password via graphical dialog")
-		var dialog = false
+		var dialog = false // swiftlint:disable:this unused_declaration
 		// periphery:ignore
 		@Argument(help: "Apple Account")
-		var appleAccount: String
+		var appleAccount: String // swiftlint:disable:this unused_declaration
 		@Argument(help: "Password")
-		var password = ""
+		var password = "" // swiftlint:disable:this unused_declaration
 
 		/// Runs the command.
 		func run() throws {
+			try mas.run { try run(printer: $0) }
+		}
+
+		func run(printer _: Printer) throws {
 			// Signing in is no longer possible as of High Sierra.
 			// https://github.com/mas-cli/mas/issues/164
 			throw MASError.notSupported
