@@ -1,15 +1,15 @@
 //
-//  SignOut.swift
-//  mas
+// SignOut.swift
+// mas
 //
-//  Created by Andrew Naylor on 14/02/2016.
-//  Copyright © 2016 Andrew Naylor. All rights reserved.
+// Copyright © 2016 mas-cli. All rights reserved.
 //
 
-import ArgumentParser
-import CommerceKit
+internal import ArgumentParser
+private import StoreFoundation
 
 extension MAS {
+	/// Signs out of the Apple Account currently signed in to the Mac App Store.
 	struct SignOut: ParsableCommand {
 		static let configuration = CommandConfiguration(
 			commandName: "signout",
@@ -18,6 +18,10 @@ extension MAS {
 
 		/// Runs the command.
 		func run() throws {
+			try mas.run { run(printer: $0) }
+		}
+
+		func run(printer _: Printer) {
 			ISServiceProxy.genericShared().accountService.signOut()
 		}
 	}
