@@ -1,12 +1,11 @@
 //
-//  AppInfoFormatter.swift
-//  mas
+// AppInfoFormatter.swift
+// mas
 //
-//  Created by Ben Chatelain on 1/7/19.
-//  Copyright © 2019 mas-cli. All rights reserved.
+// Copyright © 2019 mas-cli. All rights reserved.
 //
 
-import Foundation
+private import Foundation
 
 /// Formats text output for the info command.
 enum AppInfoFormatter {
@@ -16,7 +15,7 @@ enum AppInfoFormatter {
 	/// - Returns: Multiline text output.
 	static func format(app: SearchResult) -> String {
 		"""
-		\(app.trackName) \(app.version) [\(app.displayPrice)]
+		\(app.trackName) \(app.version) [\(app.outputPrice)]
 		By: \(app.sellerName)
 		Released: \(humanReadableDate(app.currentVersionReleaseDate))
 		Minimum OS: \(app.minimumOsVersion)
@@ -38,10 +37,9 @@ enum AppInfoFormatter {
 	/// - Parameter serverDate: String containing a date in ISO-8601 format.
 	/// - Returns: Simple date format.
 	private static func humanReadableDate(_ serverDate: String) -> String {
-		ISO8601DateFormatter().date(from: serverDate)
-			.map { date in
-				ISO8601DateFormatter.string(from: date, timeZone: .current, formatOptions: [.withFullDate])
-			}
-			?? ""
+		ISO8601DateFormatter().date(from: serverDate).map { date in
+			ISO8601DateFormatter.string(from: date, timeZone: .current, formatOptions: [.withFullDate])
+		} // swiftformat:disable:next indent
+		?? ""
 	}
 }
