@@ -1,9 +1,8 @@
 //
-//  SearchResultFormatter.swift
-//  mas
+// SearchResultFormatter.swift
+// mas
 //
-//  Created by Ben Chatelain on 1/11/19.
-//  Copyright © 2019 mas-cli. All rights reserved.
+// Copyright © 2019 mas-cli. All rights reserved.
 //
 
 /// Formats text output for the search command.
@@ -15,20 +14,19 @@ enum SearchResultFormatter {
 	///   - includePrice: Indicates whether to include prices in the output
 	/// - Returns: Multiline text output.
 	static func format(_ results: [SearchResult], includePrice: Bool = false) -> String {
-		// longest app name for right space padding
 		guard let maxAppNameLength = results.map(\.trackName.count).max() else {
 			return ""
 		}
 
 		return
 			results.map { result in
-				let appID = result.trackId
-				let appName = result.trackName.padding(toLength: maxAppNameLength, withPad: " ", startingAt: 0)
-				let version = result.version
-
-				return includePrice
-					? String(format: "%12lu  %@  (%@)  %@", appID, appName, version, result.displayPrice)
-					: String(format: "%12lu  %@  (%@)", appID, appName, version)
+				String(
+					format: includePrice ? "%12lu  %@  (%@)  %@" : "%12lu  %@  (%@)",
+					result.trackId,
+					result.trackName.padding(toLength: maxAppNameLength, withPad: " ", startingAt: 0),
+					result.version,
+					result.outputPrice
+				)
 			}
 			.joined(separator: "\n")
 	}
