@@ -1,12 +1,11 @@
 //
-//  MAS.swift
-//  mas
+// MAS.swift
+// mas
 //
-//  Created by Chris Araman on 4/22/21.
-//  Copyright © 2021 mas-cli. All rights reserved.
+// Copyright © 2021 mas-cli. All rights reserved.
 //
 
-import ArgumentParser
+internal import ArgumentParser
 
 @main
 struct MAS: AsyncParsableCommand {
