@@ -1,24 +1,27 @@
 //
-//  InstalledApp.swift
-//  mas
+// InstalledApp.swift
+// mas
 //
-//  Created by Ben Chatelain on 12/27/18.
-//  Copyright © 2018 mas-cli. All rights reserved.
+// Copyright © 2018 mas-cli. All rights reserved.
 //
 
-import Foundation
-import Version
+private import Foundation
+private import Version
 
-struct InstalledApp: Sendable {
+struct InstalledApp: Hashable, Sendable {
 	let id: AppID
-	let name: String
 	// periphery:ignore
 	let bundleID: String
+	let name: String
 	let path: String
 	let version: String
 }
 
 extension InstalledApp {
+	var idAndName: String {
+		"app ID \(id) (\(name))"
+	}
+
 	/// Determines whether the app is considered outdated.
 	///
 	/// Updates that require a higher OS version are excluded.
@@ -40,18 +43,16 @@ extension InstalledApp {
 
 		// The App Store does not enforce semantic versioning, but we assume most apps follow versioning
 		// schemes that increase numerically over time.
-		// swift-format-ignore
-		return
-			if
-				let semanticBundleVersion = Version(tolerant: version),
-				let semanticAppStoreVersion = Version(tolerant: storeApp.version)
-			{
-				semanticBundleVersion < semanticAppStoreVersion
-			} else {
-				// If a version string can't be parsed as a Semantic Version, our best effort is to
-				// check for equality. The only version that matters is the one in the App Store.
-				// https://semver.org
-				version != storeApp.version
-			}
+		return if
+			let semanticBundleVersion = Version(tolerant: version),
+			let semanticAppStoreVersion = Version(tolerant: storeApp.version)
+		{
+			semanticBundleVersion < semanticAppStoreVersion
+		} else {
+			// If a version string can't be parsed as a Semantic Version, our best effort is to
+			// check for equality. The only version that matters is the one in the App Store.
+			// https://semver.org
+			version != storeApp.version
+		}
 	}
 }
