@@ -1,9 +1,8 @@
 //
-//  SearchResult.swift
-//  mas
+// SearchResult.swift
+// mas
 //
-//  Created by Ben Chatelain on 12/29/18.
-//  Copyright © 2018 mas-cli. All rights reserved.
+// Copyright © 2018 mas-cli. All rights reserved.
 //
 
 struct SearchResult: Decodable {
@@ -20,7 +19,7 @@ struct SearchResult: Decodable {
 }
 
 extension SearchResult {
-	var displayPrice: String {
+	var outputPrice: String {
 		formattedPrice ?? "?"
 	}
 }
