@@ -1,12 +1,11 @@
 //
-//  URL.swift
-//  mas
+// URL.swift
+// mas
 //
-//  Created by Ross Goldberg on 2024-10-28.
-//  Copyright © 2024 mas-cli. All rights reserved.
+// Copyright © 2024 mas-cli. All rights reserved.
 //
 
-import AppKit
+private import AppKit
 
 extension URL {
 	func open() async throws {
