@@ -1,18 +1,28 @@
 //
-//  ProcessInfo.swift
-//  mas
+// ProcessInfo.swift
+// mas
 //
-//  Created by Ross Goldberg on 2024-10-29.
-//  Copyright © 2024 mas-cli. All rights reserved.
+// Copyright © 2024 mas-cli. All rights reserved.
 //
 
-import Foundation
+internal import Foundation
 
 extension ProcessInfo {
-	var sudoUsername: String? {
+	var sudoUserName: String? {
 		environment["SUDO_USER"]
 	}
 
+	var sudoGroupName: String? {
+		guard
+			let sudoGID,
+			let group = getgrgid(sudoGID)
+		else {
+			return nil
+		}
+
+		return String(validatingUTF8: group.pointee.gr_name)
+	}
+
 	var sudoUID: uid_t? {
 		if let uid = environment["SUDO_UID"] {
 			uid_t(uid)
