@@ -1,26 +1,25 @@
 //
-//  InfoSpec.swift
-//  masTests
+// InfoSpec.swift
+// masTests
 //
-//  Created by Ben Chatelain on 2018-12-28.
-//  Copyright © 2018 mas-cli. All rights reserved.
+// Copyright © 2018 mas-cli. All rights reserved.
 //
 
-import Nimble
+private import ArgumentParser
+@testable private import mas
+private import Nimble
 import Quick
 
-@testable import mas
-
-public final class InfoSpec: AsyncSpec {
-	override public static func spec() {
+final class InfoSpec: AsyncSpec {
+	override static func spec() {
 		describe("Info command") {
 			it("can't find app with unknown ID") {
 				await expecta(
 					await consequencesOf(try await MAS.Info.parse(["999"]).run(searcher: MockAppStoreSearcher()))
 				)
-					== (MASError.unknownAppID(999), "", "")
+					== UnvaluedConsequences(ExitCode(1), "", "Error: No apps found in the Mac App Store for app ID 999\n")
 			}
-			it("displays app details") {
+			it("outputs app details") {
 				let mockResult = SearchResult(
 					currentVersionReleaseDate: "2019-01-07T18:53:13Z",
 					fileSizeBytes: "1024",
@@ -34,11 +33,12 @@ public final class InfoSpec: AsyncSpec {
 				)
 				await expecta(
 					await consequencesOf(
-						try await MAS.Info.parse([String(mockResult.trackId)])
-							.run(searcher: MockAppStoreSearcher([mockResult.trackId: mockResult]))
+						try await MAS.Info.parse([String(mockResult.trackId)]).run(
+							searcher: MockAppStoreSearcher([mockResult.trackId: mockResult])
+						)
 					)
 				)
-					== (
+					== UnvaluedConsequences(
 						nil,
 						"""
 						Awesome App 1.0 [$2.00]
@@ -48,8 +48,7 @@ public final class InfoSpec: AsyncSpec {
 						Size: 1 KB
 						From: https://awesome.app
 
-						""",
-						""
+						"""
 					)
 			}
 		}
