@@ -1,23 +1,22 @@
 //
-//  ListSpec.swift
-//  masTests
+// ListSpec.swift
+// masTests
 //
-//  Created by Ben Chatelain on 2018-12-27.
-//  Copyright © 2018 mas-cli. All rights reserved.
+// Copyright © 2018 mas-cli. All rights reserved.
 //
 
-import Nimble
+private import ArgumentParser
+@testable private import mas
+private import Nimble
 import Quick
 
-@testable import mas
-
-public final class ListSpec: QuickSpec {
-	override public static func spec() {
+final class ListSpec: QuickSpec {
+	override static func spec() {
 		describe("list command") {
 			it("lists apps") {
 				expect(consequencesOf(try MAS.List.parse([]).run(installedApps: [])))
-					== (
-						nil,
+					== UnvaluedConsequences(
+						ExitCode(1),
 						"",
 						"""
 						Error: No installed apps found
