@@ -1,23 +1,21 @@
 //
-//  UninstallSpec.swift
-//  masTests
+// UninstallSpec.swift
+// masTests
 //
-//  Created by Ben Chatelain on 2018-12-27.
-//  Copyright © 2018 mas-cli. All rights reserved.
+// Copyright © 2018 mas-cli. All rights reserved.
 //
 
-import Nimble
+@testable private import mas
+private import Nimble
 import Quick
 
-@testable import mas
-
-public final class UninstallSpec: QuickSpec {
-	override public static func spec() {
+final class UninstallSpec: QuickSpec {
+	override static func spec() {
 		let appID = 12345 as AppID
 		let app = InstalledApp(
 			id: appID,
-			name: "Some App",
 			bundleID: "com.some.app",
+			name: "Some App",
 			path: "/tmp/Some.app",
 			version: "1.0"
 		)
@@ -30,7 +28,7 @@ public final class UninstallSpec: QuickSpec {
 							try MAS.Uninstall.parse(["--dry-run", String(appID)]).run(installedApps: [])
 						)
 					)
-						== (MASError.notInstalled(appID: appID), "", "")
+						== UnvaluedConsequences(nil, "No installed apps with app ID \(appID)")
 				}
 				it("finds an app") {
 					expect(
@@ -38,7 +36,7 @@ public final class UninstallSpec: QuickSpec {
 							try MAS.Uninstall.parse(["--dry-run", String(appID)]).run(installedApps: [app])
 						)
 					)
-						== (nil, "==> 'Some App' '/tmp/Some.app'\n==> (not removed, dry run)\n", "")
+						== UnvaluedConsequences(nil, "==> 'Some App' '/tmp/Some.app'\n==> (not removed, dry run)\n")
 				}
 			}
 			context("wet run") {
@@ -48,7 +46,7 @@ public final class UninstallSpec: QuickSpec {
 							try MAS.Uninstall.parse([String(appID)]).run(installedApps: [])
 						)
 					)
-						== (MASError.notInstalled(appID: appID), "", "")
+						== UnvaluedConsequences(nil, "No installed apps with app ID \(appID)")
 				}
 				it("removes an app") {
 					expect(
@@ -56,7 +54,7 @@ public final class UninstallSpec: QuickSpec {
 							try MAS.Uninstall.parse([String(appID)]).run(installedApps: [app])
 						)
 					)
-						== (nil, "", "")
+						== UnvaluedConsequences()
 				}
 			}
 		}
