@@ -1,12 +1,11 @@
 //
-//  MockAppStoreSearcher.swift
-//  masTests
+// MockAppStoreSearcher.swift
+// masTests
 //
-//  Created by Ben Chatelain on 1/4/19.
-//  Copyright © 2019 mas-cli. All rights reserved.
+// Copyright © 2019 mas-cli. All rights reserved.
 //
 
-@testable import mas
+@testable internal import mas
 
 struct MockAppStoreSearcher: AppStoreSearcher {
 	let apps: [AppID: SearchResult]
