@@ -1,35 +1,32 @@
 //
-//  AppListFormatterSpec.swift
-//  masTests
+// AppListFormatterSpec.swift
+// masTests
 //
-//  Created by Ben Chatelain on 8/23/2020.
-//  Copyright © 2020 mas-cli. All rights reserved.
+// Copyright © 2020 mas-cli. All rights reserved.
 //
 
-import Nimble
+@testable private import mas
+private import Nimble
 import Quick
 
-@testable import mas
-
-public final class AppListFormatterSpec: QuickSpec {
-	override public static func spec() {
-		// static func reference
+final class AppListFormatterSpec: QuickSpec {
+	override static func spec() {
+		// Static func reference
 		let format = AppListFormatter.format(_:)
 
 		describe("app list formatter") {
 			it("formats nothing as empty string") {
-				expect(consequencesOf(format([]))) == ("", nil, "", "")
+				expect(consequencesOf(format([]))) == ValuedConsequences("")
 			}
 			it("can format a single installed app") {
 				let installedApp = InstalledApp(
 					id: 12345,
-					name: "Awesome App",
 					bundleID: "",
+					name: "Awesome App",
 					path: "",
 					version: "19.2.1"
 				)
-				expect(consequencesOf(format([installedApp])))
-					== ("12345       Awesome App  (19.2.1)", nil, "", "")
+				expect(consequencesOf(format([installedApp]))) == ValuedConsequences("12345       Awesome App  (19.2.1)")
 			}
 			it("can format two installed apps") {
 				expect(
@@ -38,15 +35,15 @@ public final class AppListFormatterSpec: QuickSpec {
 							[
 								InstalledApp(
 									id: 12345,
-									name: "Awesome App",
 									bundleID: "",
+									name: "Awesome App",
 									path: "",
 									version: "19.2.1"
 								),
 								InstalledApp(
 									id: 67890,
-									name: "Even Better App",
 									bundleID: "",
+									name: "Even Better App",
 									path: "",
 									version: "1.2.0"
 								),
@@ -54,7 +51,7 @@ public final class AppListFormatterSpec: QuickSpec {
 						)
 					)
 				)
-					== ("12345       Awesome App      (19.2.1)\n67890       Even Better App  (1.2.0)", nil, "", "")
+					== ValuedConsequences("12345       Awesome App      (19.2.1)\n67890       Even Better App  (1.2.0)")
 			}
 		}
 	}
