@@ -1,34 +1,30 @@
 //
-//  InstalledAppSpec.swift
-//  masTests
+// InstalledAppSpec.swift
+// masTests
 //
-//  Created by Ben Chatelain on 9/30/21.
-//  Copyright © 2018 mas-cli. All rights reserved.
+// Copyright © 2021 mas-cli. All rights reserved.
 //
 
-import Nimble
+@testable private import mas
+private import Nimble
 import Quick
 
-@testable import mas
-
-public final class InstalledAppSpec: QuickSpec {
-	override public static func spec() {
+final class InstalledAppSpec: QuickSpec {
+	override static func spec() {
 		let app = InstalledApp(
 			id: 111,
-			name: "App",
 			bundleID: "",
+			name: "App",
 			path: "",
 			version: "1.0.0"
 		)
 
 		describe("installed app") {
 			it("is not outdated when there is no new version available") {
-				expect(consequencesOf(app.isOutdated(comparedTo: SearchResult(version: "1.0.0"))))
-					== (false, nil, "", "")
+				expect(consequencesOf(app.isOutdated(comparedTo: SearchResult(version: "1.0.0")))) == ValuedConsequences(false)
 			}
 			it("is outdated when there is a new version available") {
-				expect(consequencesOf(app.isOutdated(comparedTo: SearchResult(version: "2.0.0"))))
-					== (true, nil, "", "")
+				expect(consequencesOf(app.isOutdated(comparedTo: SearchResult(version: "2.0.0")))) == ValuedConsequences(true)
 			}
 			it("is not outdated when the new version of mac-software requires a higher OS version") {
 				expect(
@@ -36,7 +32,7 @@ public final class InstalledAppSpec: QuickSpec {
 						app.isOutdated(comparedTo: SearchResult(minimumOsVersion: "99.0.0", version: "3.0.0"))
 					)
 				)
-					== (false, nil, "", "")
+					== ValuedConsequences(false)
 			}
 			it("is not outdated when the new version of software requires a higher OS version") {
 				expect(
@@ -44,7 +40,7 @@ public final class InstalledAppSpec: QuickSpec {
 						app.isOutdated(comparedTo: SearchResult(minimumOsVersion: "99.0.0", version: "3.0.0"))
 					)
 				)
-					== (false, nil, "", "")
+					== ValuedConsequences(false)
 			}
 		}
 	}
